/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.core;

import java.io.IOException;

/**
 * This is the way to implement something like KeyListener in console
 * applications. This Thread will listen keystroke and if enter is pressed it
 * will call proper methods. To use this class it is needed to override and
 * implement it's methods onPause and onResume in derived class (hook design
 * pattern).
 * 
 * @author maka
 */
public class PauseListener extends Thread {

    private boolean paused = false;

    @Override
    public void run() {
        while (true) {
            try {
                sleep(500);
                // read all input characters and expect enter
                while (System.in.available() > 0) {
                    System.in.read();
                    // only for last one character we do something
                    if (System.in.available() == 0) {
                        paused = !paused;
                        if (paused)
                            onPause();
                        else
                            onResume();
                    }
                }

            } catch (IOException e) {
                // swallow exception
            } catch (InterruptedException e) {
                // swallow exception
            }
        }
    }

    /**
     * override this function if want to do something when pause event is
     * happened
     */
    public void onPause() {
        // override and implement me
    }

    /**
     * override this function if want to do something when resume event is
     * happened
     */
    public void onResume() {
        // override and implement me
    }
}
