/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines;

import java.util.List;

/**
 * This is interface which must implement all code search engine parsers in this
 * program.
 * 
 * @author maka:
 */
public interface ISearchEngine {

    /**
     * Checks if code part exist on this code search engine
     * 
     * @param possibleCopyAndPastedCode code currently being checked
     * @return boolean - true if this code is found on search engine
     */
    boolean isCodeFound(String possibleCopyAndPastedCode);

    /**
     * This method can return search results with link where we can see exactly
     * what is found
     * 
     * @return list of SearchResults for report if code is found on search
     *         engine
     */
    List<SearchResult> getSearchResults();
}
