/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines;

import java.io.IOException;

import com.google.gdata.util.ServiceException;

/**
 * This interface defines one function to implement. This function can retrieve
 * information about potentially plagiarised code from search engine.
 * 
 * @author maka
 */
public interface Managable {
    /**
     * This function can retrieve information about potentially plagiarised code
     * from search engine. NOTE: for now there are only this types of exceptions
     * 
     * @param possibleCopyAndPastedCode code currently being checked
     * @return information about if code is found
     * @throws IOException
     * @throws ServiceException
     */
    boolean queryEngine(String possibleCopyAndPastedCode) throws IOException, ServiceException;
}
