/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines;

import java.util.ArrayList;
import java.util.List;

/**
 * This class is basic result from code search engine. It consist information
 * about query and retrieved result.
 */
public class SearchResult {
    // project name/title
    private String projectName;
    // class name or filename
    private String className;
    // license read from site
    private String licence = "";
    // language in which this code part is written
    private String language = "";
    // name of owner of file if it is specified
    private String owner;
    // whole code which is passed for searching
    private String codeForQuery;
    // whole class where matching is found
    private String codeInClass = "";
    // code which is identical in result and query in proper format
    // this is usually bold/colored text in search results
    private List<String> matchedCode = new ArrayList<String>();
    // link to result on site
    private String link;
    // engine where code is found
    private String engine;
    // package name
    private String packageName;

    /**
     * @return package name of source code file
     */
    public String getPackageName() {
        return packageName;
    }

    /**
     * Set package name of source code file
     * 
     * @param packageName package name of source code file
     */
    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    /**
     * Set license of source code
     * 
     * @param licence license of source code
     */
    public void setLicence(String licence) {
        this.licence = licence;
    }

    /**
     * @return license of source code
     */
    public String getLicence() {
        return licence;
    }

    /**
     * Set programming language of source code
     * 
     * @param language programming language of source code
     */
    public void setLanguage(String language) {
        this.language = language;
    }

    /**
     * @return programming language of source code
     */
    public String getLanguage() {
        return language;
    }

    /**
     * Set name of code owner
     * 
     * @param owner name of code owner
     */
    public void setOwner(String owner) {
        this.owner = owner;
    }

    /**
     * @return name of code owner
     */
    public String getOwner() {
        return owner;
    }

    /**
     * Set project name
     * 
     * @param projectName
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * @return project name
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * Set possible plagiarised code
     * 
     * @param codeForQuery
     */
    public void setCodeForQuery(String codeForQuery) {
        this.codeForQuery = codeForQuery;
    }

    /**
     * @return possible plagiarised code
     */
    public String getCodeForQuery() {
        return codeForQuery;
    }

    /**
     * Set list of matched code parts
     * 
     * @param matchedCode list of matched code parts
     */
    public void setMatchedCode(List<String> matchedCode) {
        this.matchedCode = matchedCode;
    }

    /**
     * @return list of matched code parts
     */
    public List<String> getMatchedCode() {
        return matchedCode;
    }

    /**
     * Set source file name
     * 
     * @param className source file name
     */
    public void setClassName(String className) {
        this.className = className;
    }

    /**
     * @return source file name
     */
    public String getClassName() {
        return className;
    }

    /**
     * Set code in class
     * 
     * @param codeInClass raw code in class
     */
    public void setCodeInClass(String codeInClass) {
        this.codeInClass = codeInClass;
    }

    /**
     * @return code in class
     */
    public String getCodeInClass() {
        return codeInClass;
    }

    /**
     * Set URL to site where code is found
     * 
     * @param link URL to site where code is found
     */
    public void setLink(String link) {
        this.link = link;
    }

    /**
     * @return URL to site where code is found
     */
    public String getLink() {
        return link;
    }

    /**
     * Set name of CodeSearchEngine
     * 
     * @param engine name of CodeSearchEngine
     */
    public void setEngine(String engine) {
        this.engine = engine;
    }

    /**
     * @return name of CodeSearchEngine
     */
    public String getEngine() {
        return engine;
    }
}
