/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic;

/**
 * This class gives informations to the algorithm about what was found by
 * certain heuristic checker.
 * 
 * @author maka
 */
public class HeuristicCheckerResult {

    /**
     * This parameter will be set as true if check on Internet is needed.
     */
    private final boolean checkOnInternetNeaded;

    /**
     * This parameter give us the name of heuristic checker which recognize this
     * code.
     */
    private final Class<? extends IHeuristicChecker> foundBy;

    /**
     * This parameter gives informations to the algorithm if he can increase to
     * the right.
     */
    private final boolean shouldStretch;

    /**
     * This parameter marks recognized part of a code which should be checked on
     * search engines.
     */
    private final String codeSugsestedTobeChecked;

    /**
     * @param checkOnInternetNeaded information is search on on Internet needed
     * @param shouldStretch information for sliding algorithm to continue to
     *        stretch
     * @param codeSugestedToCheck code suggested for check by particular
     *        heuristic checker
     * @param foundBy name of heuristic checker found this code part
     */
    public HeuristicCheckerResult(final boolean checkOnInternetNeaded, final boolean shouldStretch,
            final String codeSugsestedToCheck, final Class<? extends IHeuristicChecker> foundBy) {
        this.checkOnInternetNeaded = checkOnInternetNeaded;
        this.shouldStretch = shouldStretch;
        this.codeSugsestedTobeChecked = codeSugsestedToCheck;
        this.foundBy = foundBy;
    }

    /**
     * @return code suggested for check by particular heuristic checker
     */
    public String getCodeSuggestedToBeChecked() {
        return codeSugsestedTobeChecked;
    }

    /**
     * @return information for sliding algorithm to continue to stretch
     */
    public boolean isShouldStretch() {
        return shouldStretch;
    }

    /**
     * @return name of heuristic checker found this code part
     */
    public Class<? extends IHeuristicChecker> getFoundBy() {
        return foundBy;
    }

    /**
     * @return information is search on on Internet needed
     */
    public boolean isCheckOnInternetNeaded() {
        return checkOnInternetNeaded;
    }
}