/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic;

/**
 * All heuristic for good-to-be-copied code will implements this
 * 
 * @author: maka
 */
public interface IHeuristicChecker {

    /**
     * if language is not important we use this constant
     */
    static final String ALL_LANGUAGES = "ALL_LANGUAGES";

    /**
     * This method knows is codeToBeChecked part of good-to-be-copied code. If
     * it is, method will return true in checkOnInternetNeaded property of
     * HeuristicCheckerResult.
     * 
     * @param codeToBeChecked possible good-to-be-copied code
     * @return HeuristicCheckerResult information generated for sliding window
     *         algorithm
     */
    HeuristicCheckerResult checkByHeuristic(String codeToBeChecked);

    /**
     * @return name of programming language
     */
    String getLanguage();

}
