/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */

package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * Comments in Cobol are defined with an asterisk at seventh character position
 * and ends when line ends, while the first six character positions are reserved
 * for sequence numbers. More info on:
 * http://www.csis.ul.ie/cobol/Course/COBOLIntro.htm
 * 
 * @author maka
 */
public class CobolCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Cobol.
     */
    private static final String COBOL_COMMENT_REGEX = "^\\d{6}\\*.*[\\n\\r]";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public CobolCommentHeuristicChecker(int limit, PrintStream out) {
        super(COBOL_COMMENT_REGEX, limit, "cobol", out);

    }

}
