/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * Comments in Delphi can be block comments and line comments. There are two
 * type of block comments. First start with { and ends with } and the second one
 * starts with (* and ends with *) Line comments in Delphi starts with // and
 * ends with an end of a line. More info on:
 * http://delphi.about.com/od/beginners/l/aa101502a.htm
 * 
 * @author maka
 */
public class DelphiCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Delphi.
     */
    private static final String DELPHI_COMMENT_REGEX = "(\\{[\\s\\S]*\\}[\\n\\r]*)|(\\(\\*[\\s\\S]*\\*\\))|(//.*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public DelphiCommentHeuristicChecker(int limit, PrintStream out) {
        super(DELPHI_COMMENT_REGEX, limit, "pascal", out);
    }

}
