/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are four types of comments in Fortran. They are all one-line comments
 * and they start with ! or C or c or * and ends when line ends. More info on:
 * http://folk.uio.no/steikr/doc/f77/tutorial/basics.html
 * 
 * @author maka
 */
public class FortranCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Fortran.
     */
    private static final String FORTRAN_COMMENT_REGEX = "(!.*[\\n\\r])|(^C .*[\\n\\r])|(^c .*[\\n\\r])|(^\\* .*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public FortranCommentHeuristicChecker(int limit, PrintStream out) {
        super(FORTRAN_COMMENT_REGEX, limit, "fortran", out);
    }

}
