/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */

package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

import org.apache.rat.pd.heuristic.IHeuristicChecker;

/**
 * A comment declaration in HTML starts with <!, followed by zero or more
 * comments, followed by >. A comment starts and ends with "--", and does not
 * contain any occurrence of "--". More info about comments in HTML on:
 * http://htmlhelp.com/reference/wilbur/misc/comment.html
 * 
 * @author maka
 */
public class HTMLCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in HTML allowing zero or more
     * comments in comment declaration. More info about regular expression to
     * match comments on: http://ostermiller.org/findhtmlcomment.html
     */
    private static final String HTML_COMMENT_REGEX = "(<!((--([^\\-]|[\\r\\n]|-[^\\-])*--(\\s)*))*>)";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public HTMLCommentHeuristicChecker(int limit, PrintStream out) {
        super(HTML_COMMENT_REGEX, limit, IHeuristicChecker.ALL_LANGUAGES, out);
    }

}
