/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are two types of comments in java one starts with // and ends when line
 * ends; second starts with /* and ends with * /. More info on:
 * http://hanuska.blogspot.com/2006/08/comments-in-java-code.html
 * 
 * @author maka
 */
public class JavaCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Java.
     */
    private static final String JAVA_COMMENT_REGEX = "(/\\*[\\s\\S]*\\*+/[\\n\\r]*)|(//.*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public JavaCommentHeuristicChecker(int limit, PrintStream out) {
        super(JAVA_COMMENT_REGEX, limit, "java", out);

    }

}
