/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are two types of comments in Lisp. A line comments in Lisp starts with
 * ; and ends with a end of a line. Block comments in Lisp starts with #| and
 * ends with |# More info on:
 * http://www.cc.gatech.edu/computing/classes/cs2360/ghall
 * /style/com_mechanics.html
 * 
 * @author maka
 */
public class LispCommentHeuristicChecker extends CommentHeuristicChecker {
    /**
     * This regular expression matches comments in Lisp.
     */
    private static final String LISP_COMMENT_REGEX = "(#\\|[\\s\\S]*\\|#)|(;.*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public LispCommentHeuristicChecker(int limit, PrintStream out) {
        super(LISP_COMMENT_REGEX, limit, "lisp", out);
    }
}
