/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are two types of a line comments and one type of block comments in PHP.
 * Block comments in PHP starts with / * and ends with * / First type of a line
 * comment in PHP starts with # and ends when the line ends. Second type of a
 * line comments in PHP starts with // and ends when the line ends. More info
 * about that can be found here: http://www.tizag.com/phpT/comment.php
 * 
 * @author maka
 */
public class PHPCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in PHP.
     */
    private static final String PHP_COMMENT_REGEX = "(#.*[\\n\\r])|(/\\*[\\s\\S]*\\*+/[\\n\\r]*)|(//.*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public PHPCommentHeuristicChecker(int limit, PrintStream out) {
        super(PHP_COMMENT_REGEX, limit, "php", out);
    }

}
