/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are 4 types of comments allowed in standard Pascal: <li>1.{this is a
 * valid comment} <li>2.(*this is a valid comment too} <li>3.(*this is a valid
 * comment*) <li>4.{this is a valid comment*)
 * <p>
 * This class recognize only pure comments, without text before or after it.
 * 
 * @author maka
 */
public class PascalCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Pascal. More info on:{@link}
     * http://search.cpan.org/~abigail/Regexp-Common-2.122/lib/Regexp/Common/
     * comment.pm
     */
    private static final String PASCAL_COMMENT_REGEX = "(\\{.*\\})|(\\{.*\\*\\))|(\\(\\*.*\\*\\))|(\\(\\*.*\\})";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public PascalCommentHeuristicChecker(int limit, PrintStream out) {
        super(PASCAL_COMMENT_REGEX, limit, "pascal", out);
    }
}
