/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There is only one type of comments in Perl. Perl uses comments that start
 * with a #, and continue till the end of the line. More info on:
 * http://www.tizag.com/perlT/perlsyntax.php
 * 
 * @author maka:
 */

public class PerlCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Perl. More info on:{@link}
     * http://search.cpan.org/~abigail/Regexp-Common-2.122/lib/Regexp/Common/
     * comment.pm
     */
    private static final String PERL_COMMENT_REGEX = "(#.*[\\n\\r])";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public PerlCommentHeuristicChecker(int limit, PrintStream out) {
        super(PERL_COMMENT_REGEX, limit, "perl", out);
    }

}
