/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

/**
 * There are two types of comments in Python. Python uses comments that start
 * with a #, and continue till the end of the line and uses triple-quotes for
 * block comments. More info on:
 * http://mail.python.org/pipermail/tutor/2004-February/028432.html
 * 
 * @author maka
 */
public class PythonCommentHeuristicChecker extends CommentHeuristicChecker {

    /**
     * This regular expression match comments in Python.
     */
    private static final String PYTHON_COMMENT_REGEX = "(#.*[\\n\\r])|(\"\"\"[\\s\\S]*\"\"\")";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public PythonCommentHeuristicChecker(int limit, PrintStream out) {
        super(PYTHON_COMMENT_REGEX, limit, "python", out);
    }

}
