/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import java.io.PrintStream;

import org.apache.rat.pd.heuristic.IHeuristicChecker;

/**
 * There is one type of comments in Visual Basic. It starts with a ' end last
 * till the end of a line. More info on:
 * http://www.aivosto.com/vbtips/codedoc.html
 * 
 * @author maka
 */
public class VisualBasicCommentHeuristicChecker extends CommentHeuristicChecker {
    /**
     * This regular expression match comments in VisualBasic.
     */
    private static final String VISUAL_BASIC_COMMENT_REGEX = "(\\s*\\'.*[\\n\\r])+";

    /**
     * @param limit minimal length of comment which will be considered
     * @param out print stream for logging purposes
     */
    public VisualBasicCommentHeuristicChecker(int limit, PrintStream out) {
        super(VISUAL_BASIC_COMMENT_REGEX, limit, IHeuristicChecker.ALL_LANGUAGES, out);
    }
}
