/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import java.io.PrintStream;

/**
 * This class can match C# functions. More info on: {@link}
 * http://en.wikipedia.org/wiki/C_Sharp_(programming_language)
 * 
 * @author maka
 */
public class CSharpFunctionHeuristicChecker extends FunctionHeuristicChecker {
    private static final String C_SHARP_CLOSED_BRACKET = "\\}";
    private static final String C_SHARP_OPENED_BRACKET = "\\{";

    /**
     * This is regular expression for C# function matching . More info on:
     * {@link} http://en.wikipedia.org/wiki/C_Sharp_(programming_language)
     */
    private static final String C_SHARP_FUNCTION_REGEX = "^[\t ]*[(public)(protected)(private)(static)(void)(abstract)\\w+]* +(.*)\\([^()]*?\\)(\\s)*"
            + "\\{[\\s\\S]*\\}[\n\r]*";

    /**
     * @param limit minimal length of function which will be considered
     * @param out print stream for logging purposes
     */
    public CSharpFunctionHeuristicChecker(int limit, PrintStream out) {
        super(limit, C_SHARP_FUNCTION_REGEX, C_SHARP_OPENED_BRACKET, C_SHARP_CLOSED_BRACKET, "c#", out);
    }

}
