/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import java.io.PrintStream;

/**
 * Delphi provides 2 types of subroutine - Procedures and Functions. Functions
 * are the same as procedures except that they return a value in addition to
 * executing statements. More info on:
 * http://www.delphibasics.co.uk/Article.asp?Name=Routines
 * 
 * @author maka
 */
public class DelphiFunctionHeuristicChecker extends FunctionHeuristicChecker {

    private static final String DELPHI_CLOSED_BRACKET = "(?i:END)";
    private static final String DELPHI_OPENED_BRACKET = "(?i:BEGIN)";

    /**
     * This regular expression matches functions in Delphi.
     */
    private static final String DELPHI_FUNCTION_REGEX = "(?i:function) +(.*)(\\([^()]*?\\))*(\\s)*\\: *\\w+ *;(\\s)*(?i:BEGIN)[\\s\\S]*(?i:END;)[\n\r]*";

    /**
     * This regular expression matches procedures in Delphi.
     */
    private static final String DELPHI_PROCEDURE_REGEX = "(?i:procedure) +(.*)(\\([^()]*?\\))*(\\s)*;(\\s)*(?i:BEGIN)[\\s\\S]*(?i:END;)[\n\r]*";

    /**
     * This regular expression matches subroutines in Delphi-both functions and
     * procedures.
     */
    private static final String DELPHI_SUBROUTINE_REGEX = "(" + DELPHI_FUNCTION_REGEX + ")|(" + DELPHI_PROCEDURE_REGEX
            + ")";

    /**
     * @param limit minimal length of function which will be considered
     * @param out print stream for logging purposes
     */
    public DelphiFunctionHeuristicChecker(int limit, PrintStream out) {
        super(limit, DELPHI_SUBROUTINE_REGEX, DELPHI_OPENED_BRACKET, DELPHI_CLOSED_BRACKET, "pascal", out);
    }

}
