/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import java.io.PrintStream;

/**
 * This class can match functions from JavaScript. More info about functions in
 * JavaScript: {@link} http://www.w3schools.com/jS/js_functions.asp
 * 
 * @author maka
 */
public class JavaScriptFunctionHeuristicChecker extends FunctionHeuristicChecker {

    private static final String JAVA_SCRIPT_CLOSED_BRACKET = "\\}";
    private static final String JAVA_SCRIPT_OPENED_BRACKET = "\\{";

    /**
     * This regular expression can match functions from JavaScript. More info
     * about functions in JavaScript: {@link}
     * http://www.w3schools.com/jS/js_functions.asp
     */
    private static final String JAVA_SCRIPT_FUNCTION_REGEX = "function +\\w+ *\\([^()]*?\\)\\s*\\{[\\s\\S]*\\}[\n\r]*";

    /**
     * @param limit minimal length of function which will be considered
     * @param out print stream for logging purposes
     */
    public JavaScriptFunctionHeuristicChecker(int limit, PrintStream out) {
        super(limit, JAVA_SCRIPT_FUNCTION_REGEX, JAVA_SCRIPT_OPENED_BRACKET, JAVA_SCRIPT_CLOSED_BRACKET, "javascript",
                out);
    }

}
