/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import java.io.PrintStream;

/**
 * This class recognize procedures and functions in Pascal. More info on:
 * http://www.learn-programming.za.net/programming_pascal_learn09.html
 * 
 * @author maka
 */
public class PascalFunctionHeuristicChecker extends FunctionHeuristicChecker {

    private static final String PASCAL_CLOSED_BRACKET = "(?i:END)";
    private static final String PASCAL_OPENED_BRACKET = "(?i:BEGIN)";

    /**
     * This regular expression match functions in Pascal.
     */
    private static final String PASCAL_FUNCTION_REGEX = "(?i:function) +(.*)\\([^()]*?\\)(\\s)*\\: *\\w+ *;(\\s)*(?i:BEGIN)[\\s\\S]*(?i:END;)";

    /**
     * This regular expression match procedures in Pascal.
     */
    private static final String PASCAL_PROCEDURE_REGEX = "(?i:procedure) +(.*)\\([^()]*?\\)(\\s)*;(\\s)*(?i:BEGIN)[\\s\\S]*(?i:END;)";

    /**
     * This regular expression matches procedures and functions in Pascal. Since
     * Pascal is case-insensitive program language the regular expression is
     * written in that way that it is case-insensitive for key words -
     * procedure, function, begin and end. For example: BEGIN,BeGiN and begin
     * are treated as equal.
     */
    private static final String PASCAL_SUBPROGRAM_REGEX = "(" + PASCAL_FUNCTION_REGEX + ")|(" + PASCAL_PROCEDURE_REGEX
            + ")";

    /**
     * @param limit minimal length of function which will be considered
     * @param out print stream for logging purposes
     */
    public PascalFunctionHeuristicChecker(int limit, PrintStream out) {
        super(limit, PASCAL_SUBPROGRAM_REGEX, PASCAL_OPENED_BRACKET, PASCAL_CLOSED_BRACKET, "pascal", out);
    }
}
