/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import java.io.PrintStream;

import org.apache.rat.pd.heuristic.IHeuristicChecker;

/**
 * This class can match Visual Basic functions and subroutines. More info about
 * that on: {@link}
 * http://en.wikiversity.org/wiki/Functions_and_Subroutines_in_VB6
 * 
 * @author maka
 */
public class VisualBasicFunctionHeuristicChecker extends FunctionHeuristicChecker {

    private static final String VISUAL_BASIC_OPENED_BRACKET = "\\{";
    private static final String VISUAL_BASIC_CLOSED_BRACKET = "\\}";

    /**
     * This regular expression match functions in Visual Basic which have access
     * modifier. For example :
     * <p>
     * Private Function Add(ByVal x As Integer, ByVal y As Integer) As Integer
     * <p>
     * Dim Res as integer Res = x + y Add = Res
     * <p>
     * End Function
     */
    private static final String VISUAL_BASIC_FUNCTION_REGEX_1 = "((?i:private)|(?i:public)) +Function +\\w+ *\\([^()]*?\\) *(As) +\\w+[\\s\\S]*End +Function[\n\r]*";

    /**
     * This regular expression match functions in Visual Basic which don't have
     * access modifier. For example :
     * <p>
     * Function Add(ByVal x As Integer, ByVal y As Integer) As Integer
     * <p>
     * Dim Res as integer Res = x + y Add = Res
     * <p>
     * End Function
     */
    private static final String VISUAL_BASIC_FUNCTION_REGEX_2 = "Function +\\w+ *\\([^()]*?\\) *(As) +\\w+[\\s\\S]*End +Function[\n\r]*";

    /**
     * This regular expression matches functions in Visual Basic.
     */
    private static final String VISUAL_BASIC_FUNCTION_REGEX = "(" + VISUAL_BASIC_FUNCTION_REGEX_1 + ")|("
            + VISUAL_BASIC_FUNCTION_REGEX_2 + ")";

    /**
     * This regular expression match subroutines in Visual Basic which have
     * access modifier. For example :
     * <p>
     * Private Sub Form_Load()
     * <p>
     * DisplayAdd 5, 2
     * <p>
     * End Sub
     */
    private static final String VISUAL_BASIC_SUBROUTINES_REGEX_1 = "((?i:private)|(?i:public)) +Sub +\\w+ *\\([^()]*?\\)[\\s\\S]*End +Sub[\n\r]*";

    /**
     * This regular expression match subroutines in Visual Basic which do not
     * have access modifier. For example:
     * <p>
     * Sub TestSub()
     * <p>
     * MsgBox "Code in TestSub()"
     * <p>
     * End Sub
     */
    private static final String VISUAL_BASIC_SUBROUTINES_REGEX_2 = "Sub +\\w+ *\\([^()]*?\\)[\\s\\S]*End +Sub[\n\r]*";

    /**
     * This regular expression matches subroutines in Visual Basic.
     */
    private static final String VISUAL_BASIC_SUBROUTINES_REGEX = "(" + VISUAL_BASIC_SUBROUTINES_REGEX_1 + ")|("
            + VISUAL_BASIC_SUBROUTINES_REGEX_2 + ")";

    /**
     * This regular expression matches both functions and subroutines in Visual
     * Basic.
     */
    private static final String VISUAL_BASIC_SUBPROGRAMS_REGEX = VISUAL_BASIC_FUNCTION_REGEX + "|"
            + VISUAL_BASIC_SUBROUTINES_REGEX;

    /**
     * @param limit minimal length of function which will be considered
     * @param out print stream for logging purposes
     */
    public VisualBasicFunctionHeuristicChecker(int limit, PrintStream out) {
        super(limit, VISUAL_BASIC_SUBPROGRAMS_REGEX, VISUAL_BASIC_OPENED_BRACKET, VISUAL_BASIC_CLOSED_BRACKET,
                IHeuristicChecker.ALL_LANGUAGES, out);
    }

}
