/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.misspellings;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.TreeSet;

/**
 * This is simple dictionary. It can be loaded from some resource file and can
 * return information about existence of some word in that dictionary.
 * 
 * @author maka
 */
public class Dictionary implements IDictionary {

    /**
     * When we load dictionary, this structure ensure proper order and log(n)
     * search performance
     */
    private TreeSet<String> dictionary = new TreeSet<String>();

    /**
     * @param is input stream for dictionary
     * @throws IOException
     */
    public Dictionary(InputStream is) throws IOException {
        initializeBasicSet();
        readDictionary(is);
    }

    /**
     * This method load dictionary from Input Stream
     * 
     * @param is input stream
     * @throws IOException
     */
    private void readDictionary(InputStream is) throws IOException {
        BufferedReader input = new BufferedReader(new InputStreamReader(is));
        // TODO think about this - exception can be caught here
        try {
            String line = null;
            while ((line = input.readLine()) != null) {
                dictionary.add(line.toLowerCase());
            }
        } finally {
            input.close();
        }
    }

    /**
     * We must add in dictionary alphabet letters. Single character strings are
     * not interesting to us.
     */
    private void initializeBasicSet() {
        char letter;
        for (letter = 'a'; letter <= 'z'; letter++) {
            dictionary.add(Character.toString(letter));
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.apache.rat.pd.heuristic.misspellings.IDictionary#exist(java.lang.
     * String)
     */
    public boolean exist(String toFind) {
        return dictionary.contains(toFind);
    }
}
