/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.report;

import java.util.ArrayList;
import java.util.List;

import org.apache.rat.pd.engines.SearchResult;

/**
 * Represents one suspected code part which man must check manually
 * 
 * @author maka
 */
public class ReportEntry {

    private String fileName;
    private final String code;
    List<SearchResult> searchResults = new ArrayList<SearchResult>();

    /**
     * @param searchResults list of search results
     * @param code code for query
     * @param fileName file name where code is found
     */
    public ReportEntry(final List<SearchResult> searchResults, final String code, String fileName) {
        this.searchResults.addAll(searchResults);
        this.code = code;
        this.fileName = fileName;
    }

    /**
     * @return list of search results
     */
    public List<SearchResult> getSearchResult() {
        return searchResults;
    }

    /**
     * @return code for query
     */
    public String getCode() {
        return code;
    }

    /**
     * @return source file name
     */
    public String getFileName() {
        return fileName;
    }
}
