/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.report;

import org.apache.rat.pd.engines.SearchResult;

public class TxtReportGenerator extends Report {

    /**
     * @return generate explanation about plagiarized code in txt format.
     */
    public String getReport() {
        StringBuffer sb = new StringBuffer();
        for (ReportEntry reportEntry : raportList) {
            sb.append("\n============================================\n");
            sb.append("File Name: " + reportEntry.getFileName() + "\n");
            sb.append("Part of a code suspected to be plagiarized:");
            sb.append("\n____________________________________________\n");
            sb.append("\n\t" + reportEntry.getCode().replaceAll("\n", "\n\t"));
            sb.append("\n____________________________________________\n");

            for (SearchResult searchResult : reportEntry.getSearchResult()) {
                sb.append("Class Name:\n");
                sb.append("\t" + searchResult.getClassName() + "\n");
                sb.append("Project Name: \n");
                sb.append("\t" + searchResult.getProjectName() + "\n");
                sb.append("Package Name: \n");
                sb.append("\t" + searchResult.getPackageName() + "\n");
                sb.append("License:\n");
                sb.append("\t" + searchResult.getLicence() + "\n");
                sb.append("URL for comparation:\n");
                sb.append("\t" + searchResult.getLink() + "\n");
                sb.append("Owner: \n");
                sb.append("\t" + searchResult.getOwner() + "\n");
                sb.append("Language: \n");
                sb.append("\t" + searchResult.getLanguage() + "\n");
                sb.append("Engine: \n");
                sb.append("\t" + searchResult.getEngine() + "\n");
                sb.append("Matched Code: \n");
                for (String match : searchResult.getMatchedCode()) {
                    sb.append("\t" + match + "\n");
                }
                sb.append("\n============================================\n");
            }
        }
        return sb.toString();
    }

}
