/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.report;

import java.io.IOException;
import java.io.StringWriter;

import org.apache.rat.pd.engines.SearchResult;
import org.apache.rat.report.xml.writer.IXmlWriter;
import org.apache.rat.report.xml.writer.impl.base.XmlWriter;

/**
 * This class can generate report in xml format
 * 
 * @author maka
 */
public class XmlReportGenerator extends Report {
    private StringWriter buffer = new StringWriter();
    IXmlWriter writer = new XmlWriter(buffer);

    /**
     * @return generate explanation about plagiarized code in xml format.
     */
    @Override
    public String getReport() {
        try {
            writer.startDocument();
            writer.openElement("report");
            createReportEntryList();
            writer.closeElement();
            writer.closeDocument();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return buffer.toString();
    }

    /**
     * Create xml list of report entry sub-nodes
     * 
     * @throws IOException
     */
    private void createReportEntryList() throws IOException {
        for (ReportEntry reportEntry : this.raportList) {
            writer.openElement("reportEntry");

            writer.openElement("fileName");
            writer.content(reportEntry.getFileName());
            writer.closeElement();

            writer.openElement("code");
            writer.content(reportEntry.getCode());
            writer.closeElement();

            createSearchResults(reportEntry);
            writer.closeElement();
        }
    }

    /**
     * Create xml list of search result sub-nodes
     * 
     * @throws IOException
     */
    private void createSearchResults(ReportEntry reportEntry) throws IOException {
        for (SearchResult searchResult : reportEntry.getSearchResult()) {
            writer.openElement("searchResult");

            writer.openElement("className");
            writer.content(searchResult.getClassName());
            writer.closeElement();

            writer.openElement("codeInClass");
            writer.content(searchResult.getCodeInClass());
            writer.closeElement();

            writer.openElement("searchEngine");
            writer.content(searchResult.getEngine());
            writer.closeElement();

            writer.openElement("language");
            writer.content(searchResult.getLanguage());
            writer.closeElement();

            writer.openElement("license");
            writer.content(searchResult.getLicence());
            writer.closeElement();

            writer.openElement("link");
            writer.content(searchResult.getLink());
            writer.closeElement();

            writer.openElement("owner");
            writer.content(searchResult.getOwner());
            writer.closeElement();

            writer.openElement("packageName");
            writer.content(searchResult.getPackageName());
            writer.closeElement();

            writer.openElement("projectName");
            writer.content(searchResult.getProjectName());
            writer.closeElement();

            writer.openElement("matchedCode");
            for (String match : searchResult.getMatchedCode()) {
                writer.openElement("match");
                writer.content(match);
                writer.closeElement();
            }
            writer.closeElement();

            writer.closeElement();
        }
    }
}
