/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.Writer;

public class FileManipulator {

    // TODO encoding is system default now!!!!
    /**
     * @param filename
     * @param aContents
     * @throws IOException
     */
    static public void saveFile(String filename, String aContents) throws IOException {
        Writer output = new BufferedWriter(new FileWriter(filename));
        try {
            output.write(aContents);
        } finally {
            output.close();
        }
    }

    /**
     * To read file and replace all new-line characters ( \n, \r )with "\n"
     * 
     * @param reader object which can read a file
     * @return content of file
     * @throws IOException
     */
    public static String readFile(Reader reader) throws IOException {
        String toRet = "";
        // TODO encoding is system default now!!!!
        BufferedReader input = new BufferedReader(reader);
        try {
            String line = null;
            while ((line = input.readLine()) != null) {
                toRet += line + "\n";
            }
        } finally {
            input.close();
        }
        return toRet;
    }

    /**
     * To convert the InputStream to String we use the BufferedReader.readLine()
     * method. We iterate until the BufferedReader return null which means
     * there's no more data to read. Each line will appended to a StringBuilder
     * and returned as String. It replace all new-line characters ( \n, \r )with
     * "\n".
     * 
     * @param is inputStream
     * @return string read from stream
     */
    public static String convertStreamToString(InputStream is) {

        BufferedReader reader = new BufferedReader(new InputStreamReader(is));
        StringBuilder sb = new StringBuilder();

        String line = null;
        try {
            while ((line = reader.readLine()) != null) {
                sb.append(line + "\n");
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                is.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        return sb.toString();
    }
}
