/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines.google;

import java.io.IOException;
import java.net.URL;
import java.util.Arrays;
import java.util.List;

import junit.framework.TestCase;

public class GoogleCodeSearchParserTest extends TestCase {

    private GoogleCodeSearchParser parser = new GoogleCodeSearchParser("lag", 100, System.out);

    public void testSplitLongUrl() throws IOException {
        // minimum length of search query is 95
        String[] lines = "a".split("\n *");
        List<URL> actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 95);
        assertEquals(1, actual.size());

        lines = "a\nb".split("\n *");
        actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 100);
        assertEquals(2, actual.size());

        lines = "a\nb".split("\n *");
        actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 135);
        assertEquals(1, actual.size());

        lines = "a\nb\nc".split("\n *");
        actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 100);
        assertEquals(3, actual.size());

        lines = "a\nb\nc\nd".split("\n *");
        actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 100);
        assertEquals(4, actual.size());

        lines = "".split("\n *");
        actual = parser.fitCodeLinesIntoUrls(Arrays.asList(lines), 100);
        assertEquals(1, actual.size());
    }

    public void testAllSubArrays() throws Exception {
        assertEquals("when search query us created from this string, there will be one query", 1, parser.splitOversizedLines(
                "a", 95).size());
        assertEquals("when search query us created from this string, there will be two queries", 2, parser
                .splitOversizedLines("ab", 95).size());

        assertEquals("when search query us created from this string, there will be one query", 1, parser.splitOversizedLines(
                "ab", 96).size());
        assertEquals("when search query us created from this string, there will be one query", 1, parser.splitOversizedLines(
                "test", 98).size());
        assertEquals("when search query us created from this string, there will be two queries", 2, parser
                .splitOversizedLines("test1", 98).size());

        // this is fix checking of bug
        // http://code.google.com/p/apache-rat-pd/source/detail?r=51#
        assertEquals("when search query us created from this string, there will be one query", 1, parser.splitOversizedLines(
                "/////////////////////////////////////////////////", 1024).size());
        assertEquals("when search query us created from this string, there will be two queries", 2, parser
                .splitOversizedLines("//////////////////////////////////////////////////", 1024).size());
        assertEquals("when search query us created from this string, there will be two queries", 2, parser.splitOversizedLines(
                "//////////////////////////////////////////////////////////////////////////////////////////////////",
                1024).size());
        assertEquals("when search query us created from this string, there will be three queries", 3, parser.splitOversizedLines(
                "///////////////////////////////////////////////////////////////////////////////////////////////////",
                1024).size());

    }
}
