/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines.google;

import junit.framework.TestCase;

/**
 * This regular expressions can query code when are used in Google Code Search.
 * 
 * @author maka
 */
public class MultilineRegexGeneratorTest extends TestCase {

    private RegexGenerator regexGenerator = new MultilineRegexGenerator();

    private static final String TEST_CASE_1 = "public static void main(String[] args)";
    private static final String TEST_CASE_1_EXPECTED = "^(\\s?)+public(\\s?)+static(\\s?)+"
            + "void(\\s?)+main(\\s?)+\\((\\s?)+String(\\s?)+\\[(\\s?)+\\](\\s?)+args(\\s?)+\\)";

    private static final String TEST_CASE_2 = "public class Hello world\n" + "{\n"
            + "public static void main (String args[])\n" + "{\n" + "for( int i=0 ; i < 9 ; i++ ) {\n"
            + "System.out.println(args[i]);\n" + "}\n" + "}\n" + "}\n";
    private static final String TEST_CASE_2_EXPECTED = "^(\\s?)+public(\\s?)+class(\\s?)+Hello(\\s?)+world(\\s?)+$"
            + " ^(\\s?)+\\{(\\s?)+$"
            + " ^(\\s?)+public(\\s?)+static(\\s?)+void(\\s?)+main(\\s?)+\\((\\s?)+String(\\s?)+args(\\s?)+\\[(\\s?)+\\](\\s?)+\\)(\\s?)+$"
            + " ^(\\s?)+\\{(\\s?)+$"
            + " ^(\\s?)+for(\\s?)+\\((\\s?)+int(\\s?)+i(\\s?)+=(\\s?)+0(\\s?)+;(\\s?)+i(\\s?)+<(\\s?)+9(\\s?)+;(\\s?)+i(\\s?)+\\+(\\s?)+\\+(\\s?)+\\)(\\s?)+\\{(\\s?)+$"
            + " ^(\\s?)+System(\\s?)+\\.(\\s?)+out(\\s?)+\\.(\\s?)+println(\\s?)+\\((\\s?)+args(\\s?)+\\[(\\s?)+i(\\s?)+\\](\\s?)+\\)(\\s?)+;(\\s?)+$"
            + " ^(\\s?)+\\}(\\s?)+$" + " ^(\\s?)+\\}(\\s?)+$ ^(\\s?)+\\}";

    private static final String TEST_CASE_3 = "public class HelloWorld\n" + "{\n"
            + "public static void main(String[] args)\n" + "{\n" + "System.out.println(\"Hello World!\")\n" + "}\n"
            + "}\n";
    private static final String TEST_CASE_3_EXPECTED = "^(\\s?)+public(\\s?)+class(\\s?)+HelloWorld(\\s?)+$"
            + " ^(\\s?)+\\{(\\s?)+$"
            + " ^(\\s?)+public(\\s?)+static(\\s?)+void(\\s?)+main(\\s?)+\\((\\s?)+String(\\s?)+\\[(\\s?)+\\](\\s?)+args(\\s?)+\\)(\\s?)+$"
            + " ^(\\s?)+\\{(\\s?)+$"
            + " ^(\\s?)+System(\\s?)+\\.(\\s?)+out(\\s?)+\\.(\\s?)+println(\\s?)+\\((\\s?)+\"(\\s?)+Hello(\\s?)+World!(\\s?)+\"(\\s?)+\\)(\\s?)+$"
            + " ^(\\s?)+\\}(\\s?)+$" + " ^(\\s?)+\\}";

    // maybe it is not reached the end of current line if it is last one, so it
    // can not have LINE_END regex.
    private static final String TEST_CASE_4 = "public static void main(String";
    private static final String TEST_CASE_4_EXPECTED = "^(\\s?)+public(\\s?)+static(\\s?)+"
            + "void(\\s?)+main(\\s?)+\\((\\s?)+String";

    /**
     * Test method for
     * {@link org.apache.rat.pd.engines.google.MultilineRegexGenerator#stringToRegex(java.lang.String)}
     * .
     */
    public void testStringToRegex() {
        String regex = regexGenerator.stringToRegex(TEST_CASE_1);
        System.out.println(regex);
        assertEquals("I except that regex is .....", TEST_CASE_1_EXPECTED, regex);
        System.out.println(TEST_CASE_1 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_2);
        System.out.println(regex);
        assertEquals("I except that regex is .....", TEST_CASE_2_EXPECTED, regex);
        System.out.println(TEST_CASE_2 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_3);
        System.out.println(regex);
        assertEquals("I except that regex is .....", TEST_CASE_3_EXPECTED, regex);
        System.out.println(TEST_CASE_3 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_4);
        System.out.println(regex);
        assertEquals("I except that regex is .....", TEST_CASE_4_EXPECTED, regex);
        System.out.println(TEST_CASE_4 + " --------> " + regex);
    }
}
