/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.engines.google;

import org.apache.rat.pd.engines.google.RegexGenerator;

import junit.framework.TestCase;

public class RegexGeneratorTest extends TestCase {

    private RegexGenerator regexGenerator = new RegexGenerator();
    private String TEST_CASE_1 = "public static void main(String[] args)";//()[]
    private String TEST_CASE_2 = "public static void main(String[] args){}";//{}
    private String TEST_CASE_3 = "private List<String> getArray(){ return array }";// less then and greater then
    private String TEST_CASE_4 = "this.getClass()";// dot
    private String TEST_CASE_5 = "for(String s : list)";// two dots
    private String TEST_CASE_6 = "evaluate == 1 ? true : false";// question mark
    private String TEST_CASE_7 = "/*comment*/";// slash and asterix
    private String TEST_CASE_8 = "1+2=3";// plus sign
    private String TEST_CASE_9 = "3-2=1";// minus sign
    private String TEST_CASE_10 = "this.number = number;";// semicilumn
    private String TEST_CASE_11 = "\"Hello World\"";// semicilumn
    private String TEST_CASE_12 = "$";// dollar sign
    private String TEST_CASE_13 = "^";// power sign
    private String TEST_CASE_14 = "\\a\\";// back slash

    public void testAddWhitespaceAroundDot() {
        String regex = regexGenerator.addWhitespaceAroundNonLiteral(TEST_CASE_4);
        assertEquals("I except that regex is .....", "this . getClass ( )", regex);
    }

    public void testStringToRegex() {
        String regex = regexGenerator.stringToRegex(TEST_CASE_1);
        assertEquals("I except that regex is .....", "public(\\s?)+static(\\s?)+"
                + "void(\\s?)+main(\\s?)+\\((\\s?)+String(\\s?)+\\[(\\s?)+\\](\\s?)+args(\\s?)+\\)", regex);

        System.out.println(TEST_CASE_1 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_2);
        assertEquals(
                "I except that regex is .....",
                "public(\\s?)+static(\\s?)+"
                        + "void(\\s?)+main(\\s?)+\\((\\s?)+String(\\s?)+\\[(\\s?)+\\](\\s?)+args(\\s?)+\\)(\\s?)+\\{(\\s?)+\\}",
                regex);

        System.out.println(TEST_CASE_2 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_3);
        assertEquals(
                "I except that regex is .....",
                "private(\\s?)+List(\\s?)+<(\\s?)+String(\\s?)+>(\\s?)+getArray(\\s?)+\\((\\s?)+\\)(\\s?)+\\{(\\s?)+return(\\s?)+array(\\s?)+\\}",
                regex);

        System.out.println(TEST_CASE_3 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_4);
        assertEquals("I except that regex is .....", "this(\\s?)+\\.(\\s?)+getClass(\\s?)+\\((\\s?)+\\)", regex);

        System.out.println(TEST_CASE_4 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_5);
        assertEquals("I except that regex is .....", "for(\\s?)+\\((\\s?)+String(\\s?)+s(\\s?)+:(\\s?)+list(\\s?)+\\)",
                regex);

        System.out.println(TEST_CASE_5 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_6);
        assertEquals("I except that regex is .....",
                "evaluate(\\s?)+=(\\s?)+=(\\s?)+1(\\s?)+\\?(\\s?)+true(\\s?)+:(\\s?)+false", regex);

        System.out.println(TEST_CASE_6 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_7);
        assertEquals("I except that regex is .....", "/(\\s?)+\\*(\\s?)+comment(\\s?)+\\*(\\s?)+/", regex);

        System.out.println(TEST_CASE_7 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_8);
        assertEquals("I except that regex is .....", "1(\\s?)+\\+(\\s?)+2(\\s?)+=(\\s?)+3", regex);

        System.out.println(TEST_CASE_8 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_9);
        assertEquals("I except that regex is .....", "3(\\s?)+\\-(\\s?)+2(\\s?)+=(\\s?)+1", regex);

        System.out.println(TEST_CASE_9 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_10);
        assertEquals("I except that regex is .....", "this(\\s?)+\\.(\\s?)+number(\\s?)+=(\\s?)+number(\\s?)+;", regex);

        System.out.println(TEST_CASE_10 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_11);
        assertEquals("I except that regex is .....", "\"(\\s?)+Hello(\\s?)+World(\\s?)+\"", regex);

        System.out.println(TEST_CASE_11 + " --------> " + regex);
        // there was a bug causing application to break when code consist
        // dollar character
        regex = regexGenerator.stringToRegex(TEST_CASE_12);
        assertEquals("I except that regex is .....", "\\$", regex);

        System.out.println(TEST_CASE_12 + " --------> " + regex);

        regex = regexGenerator.stringToRegex(TEST_CASE_13);
        assertEquals("I except that regex is .....", "\\^", regex);

        System.out.println(TEST_CASE_13 + " --------> " + regex);

        // there was a bug causing application to break when code consist
        // backslash character
        regex = regexGenerator.stringToRegex(TEST_CASE_14);
        assertEquals("I except that regex is .....", "\\\\a\\\\", regex);

        System.out.println(TEST_CASE_14 + " --------> " + regex);

    }

    public void testAddWhitespaceAroundNonLiteral() {
        String regex = regexGenerator.addWhitespaceAroundNonLiteral(TEST_CASE_1);
        assertEquals("I except that regex is .....", "public static " + "void main ( String [ ] args )", regex);
    }

    public void testReplaceNonLiteralWithProperRegex() {
        String regex = regexGenerator.replaceNonLiteralWithProperRegex(TEST_CASE_1);
        assertEquals("I except that regex is .....", "public static " + "void main\\(String\\[\\] args\\)", regex);
    }

    public void testReplaceWhitespaceWithRegex() {
        String regex = regexGenerator.replaceWhitespaceWithRegex(TEST_CASE_1);
        assertEquals("I except that regex is .....", "public(\\s?)+static(\\s?)+"
                + "void(\\s?)+main(String[](\\s?)+args)", regex);
    }
}
