/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import junit.framework.TestCase;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;

public class CCommentHeuristicCheckerTest extends TestCase {

    private IHeuristicChecker checker;

    private static final String SIMPLE_COMMENT_1 = "/*this is simple comment*/";
    private static final String SIMPLE_COMMENT_2 = "/*this is simple comment which is splited in \n" + "two lines*/";
    private static final String SIMPLE_COMMENT_3 = "/*this is /* */";
    private static final String VALID_COMMENT_1 = "something /* this is comment*/";

    private static final String NOT_VALID_COMMENT_1 = "/*this is comment */ something";

    protected void setUp() throws Exception {
        super.setUp();
        checker = new CCommentHeuristicChecker(5, System.out);

    }

    protected void tearDown() throws Exception {
        super.tearDown();
        checker = null;
    }

    public void testCheckByHeuristic() {
        assertEquals("There must be true returned because this is the simpliest comment in C", true, checker
                .checkByHeuristic(SIMPLE_COMMENT_1).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because it is valid comment ", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_2).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because it is valid comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_3).isCheckOnInternetNeaded());

        HeuristicCheckerResult heuristicResult = checker.checkByHeuristic(VALID_COMMENT_1);
        assertEquals("There must be true returned because we have comment in this part of code which we are checking",
                true, heuristicResult.isCheckOnInternetNeaded());
        assertEquals("Code for searching must be equals to this:", "/* this is comment*/", heuristicResult
                .getCodeSuggestedToBeChecked());

        assertEquals("There must be false returned because there is something after comment ends", false, checker
                .checkByHeuristic(NOT_VALID_COMMENT_1).isCheckOnInternetNeaded());

    }

}
