/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;
import org.apache.rat.pd.heuristic.comment.DelphiCommentHeuristicChecker;

import junit.framework.TestCase;

public class DelphiCommentHeuristicCheckerTest extends TestCase {
    private IHeuristicChecker checker;

    private static final String SIMPLE_COMMENT_1 = "// this is simple comment\n";
    private static final String SIMPLE_COMMENT_2 = "{ this is simple comment }";
    private static final String SIMPLE_COMMENT_3 = "(* this is simple comment *)";
    private static final String SIMPLE_COMMENT_4 = "{{ this is simple comment }  }}";
    private static final String SIMPLE_COMMENT_5 = "(** this is simple comment ***)";
    private static final String SIMPLE_COMMENT_6 = "(* this is simple comment\n in two lines ***)";
    private static final String VALID_COMMENT_1 = "something //this is simple comment\n";

    private static final String NOT_VALID_COMMENT_1 = "//this is simple comment";
    private static final String NOT_VALID_COMMENT_2 = "{{ this is simple comment\n in two lines }  }} something";

    /*
     * loading resource file with test data
     */
    protected void setUp() throws Exception {
        super.setUp();
        checker = new DelphiCommentHeuristicChecker(5, System.out);

    }

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
        checker = null;
    }

    public void testCheckByHeuristic() {
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_1).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_2).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_3).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_4).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_5).isCheckOnInternetNeaded());
        assertEquals("There must be true returned because this is regulal comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_6).isCheckOnInternetNeaded());

        HeuristicCheckerResult heuristicResult = checker.checkByHeuristic(VALID_COMMENT_1);

        assertEquals("There must be true returned because we have comment in this part of code which we are checking",
                true, heuristicResult.isCheckOnInternetNeaded());
        assertEquals("Code for searching must be equals to this:", "//this is simple comment\n", heuristicResult
                .getCodeSuggestedToBeChecked());

        assertEquals(
                "There must be false returned because our comment does not end with an end of a line so we only have a part of a comment",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_1).isCheckOnInternetNeaded());
        assertEquals("There must be false returned because there is something after comment", false, checker
                .checkByHeuristic(NOT_VALID_COMMENT_2).isCheckOnInternetNeaded());

    }

}
