/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.comment;

import junit.framework.TestCase;

import org.apache.rat.pd.heuristic.IHeuristicChecker;
import org.apache.rat.pd.heuristic.comment.PascalCommentHeuristicChecker;

/**
 * @author maka
 */
public class PascalCommentHeuristicCheckerTest extends TestCase {

    private IHeuristicChecker checker;

    private static final String SIMPLE_COMMENT_1 = "{this is simple comment}";
    private static final String SIMPLE_COMMENT_2 = "{this is simple comment*)";
    private static final String SIMPLE_COMMENT_3 = "(*this is simple comment*)";
    private static final String SIMPLE_COMMENT_4 = "(*this is simple comment}";
    private static final String VALID_COMMENT_1 = "something(*comment*)";

    private static final String NOT_COMMENT_1 = "(*)";
    private static final String NOT_COMMENT_2 = "(*comment*)something";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        checker = new PascalCommentHeuristicChecker(5, System.out);
    }

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#tearDown()
     */
    protected void tearDown() throws Exception {
        super.tearDown();
        checker = null;
    }

    public void testCheckByHeuristic() {
        assertEquals("There must be true returned because it is a valid comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_1).isCheckOnInternetNeaded());

        assertEquals("There must be true returned because it is a vallid comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_2).isCheckOnInternetNeaded());

        assertEquals("There must be true returned because it is a vallid comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_3).isCheckOnInternetNeaded());

        assertEquals("There must be true returned because it is a vallid comment", true, checker.checkByHeuristic(
                SIMPLE_COMMENT_4).isCheckOnInternetNeaded());

        assertEquals("There must be false returned because it is not a valid comment", false, checker.checkByHeuristic(
                NOT_COMMENT_1).isCheckOnInternetNeaded());

        assertEquals("There must be false returned because there is something after comment", false, checker
                .checkByHeuristic(NOT_COMMENT_2).isCheckOnInternetNeaded());

    }
}
