package org.apache.rat.pd.heuristic.comment;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;

import junit.framework.TestCase;

public class PythonCommentHeuristicCheckerTest extends TestCase {

    private IHeuristicChecker checker;

    private static final String SIMPLE_COMMENT_1 = "# This is a comment\n";
    private static final String SIMPLE_COMMENT_2 = "#this is also a comment\n";
    private static final String SIMPLE_COMMENT_3 = "#this is also# a comment\n";
    private static final String SIMPLE_COMMENT_4 = "\"\"\"     \"\"\"";
    private static final String SIMPLE_COMMENT_5 = "\"\"\"  comment   \"\"\"";
    private static final String SIMPLE_COMMENT_6 = "\"\"\" comment\n   \"\"\"";
    private static final String SIMPLE_COMMENT_7 = "\"\"\" \n   comment  \n   \"\"\"";
    private static final String SIMPLE_COMMENT_8 = "\"\"\" \n   comment  \n comment2   \n\n\n comment3  \"\"\"";
    private static final String VALID_COMMENT_1 = "something # this is comment\n";
    private static final String VALID_COMMENT_2 = "something\"\"\"   COMMENT  \"\"\"";

    private static final String NOT_VALID_COMMENT_1 = "#this is comment";
    private static final String NOT_VALID_COMMENT_2 = "#this is comment\n something else";
    private static final String NOT_VALID_COMMENT_3 = "#this is comment# a \n something else\n";

    protected void setUp() throws Exception {
        super.setUp();

        /**
         * Since comments have the same syntax in Ruby, Shell and Perl the same
         * tests used for Ruby will give the same result for Shell and Perl
         */
        checker = new PythonCommentHeuristicChecker(5, System.out);

    }

    protected void tearDown() throws Exception {
        super.tearDown();
        checker = null;
    }

    public void testCheckByHeuristic() {
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_1)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_2)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_3)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_4)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_5)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_6)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_7)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_8)
                .isCheckOnInternetNeaded());

        HeuristicCheckerResult heuristicResult = checker.checkByHeuristic(VALID_COMMENT_1);
        assertEquals("There must be true returned because we have comment in this part of code which we are checking",
                true, heuristicResult.isCheckOnInternetNeaded());
        assertEquals("Code for searching must be equals to this:", "# this is comment\n", heuristicResult
                .getCodeSuggestedToBeChecked());

        heuristicResult = checker.checkByHeuristic(VALID_COMMENT_2);
        assertEquals("There must be true returned because we have comment in this part of code which we are checking",
                true, heuristicResult.isCheckOnInternetNeaded());
        assertEquals("Code for searching must be equals to this:", "\"\"\"   COMMENT  \"\"\"", heuristicResult
                .getCodeSuggestedToBeChecked());

        assertEquals("There must be false returned because this comment does not end with the end of a line simbol",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_1).isCheckOnInternetNeaded());
        assertEquals(
                "There must be false returned because this comment consist something after the end of a line simbol ",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_2).isCheckOnInternetNeaded());
        assertEquals(
                "There must be false returned because this comment consist something after the end of a line simbol ",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_3).isCheckOnInternetNeaded());

    }

}
