package org.apache.rat.pd.heuristic.comment;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;
import junit.framework.TestCase;

/**
 * Since comments have the same syntax in Ruby, Shell and Perl the same tests
 * used for Ruby will give the same result for Shell and Perl
 */
public class RubyCommentHeuristicCheckerTest extends TestCase {

    private IHeuristicChecker checker;

    private static final String SIMPLE_COMMENT_1 = "# This is a comment\n";
    private static final String SIMPLE_COMMENT_2 = "#this is also a comment\n";
    private static final String SIMPLE_COMMENT_3 = "#this is also# a comment\n";
    private static final String VALID_COMMENT_1 = "something # this is comment\n";

    private static final String NOT_VALID_COMMENT_2 = "#this is comment";
    private static final String NOT_VALID_COMMENT_3 = "#this is comment\n something else";
    private static final String NOT_VALID_COMMENT_4 = "#this is comment# a \n something else\n";

    protected void setUp() throws Exception {
        super.setUp();

        /**
         * Since comments have the same syntax in Ruby, Shell and Perl the same
         * tests used for Ruby will give the same result for Shell and Perl
         */
        checker = new RubyCommentHeuristicChecker(5, System.out);

    }

    protected void tearDown() throws Exception {
        super.tearDown();

        checker = null;
    }

    public void testCheckByHeuristic() {
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_1)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_2)
                .isCheckOnInternetNeaded());
        assertEquals("There must be true returned", true, checker.checkByHeuristic(SIMPLE_COMMENT_3)
                .isCheckOnInternetNeaded());

        HeuristicCheckerResult heuristicResult = checker.checkByHeuristic(VALID_COMMENT_1);
        assertEquals("There must be true returned because we have comment in this part of code which we are checking",
                true, heuristicResult.isCheckOnInternetNeaded());
        assertEquals("Code for searching must be equals to this:", "# this is comment\n", heuristicResult
                .getCodeSuggestedToBeChecked());

        assertEquals("There must be false returned because this comment does not end with the end of a line simbol",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_2).isCheckOnInternetNeaded());
        assertEquals(
                "There must be false returned because this comment consist something after the end of a line simbol ",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_3).isCheckOnInternetNeaded());
        assertEquals(
                "There must be false returned because this comment consist something after the end of a line simbol ",
                false, checker.checkByHeuristic(NOT_VALID_COMMENT_4).isCheckOnInternetNeaded());

    }
}