/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import junit.framework.TestCase;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;

/**
 * Functions in ActionScript can exist in two ways: <li>function
 * functionName(listOfParameters){function body} <li>function
 * functionName(listOfParameters):returnType {function body}
 * 
 * @author Maka
 */
public class ActionScriptFeuristicCheckerTest extends TestCase {

    private IHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "function name():boolean {return true}";
    private static final String SIMPLE_FUNCTION_2 = "function onCaptionate(cap:Array) {"
            + "               clip.txt.htmlText = cap[capTrack];" + "               capTime = currentTime;"
            + "        }";
    private static final String SIMPLE_FUNCTION_3 = "function   name  (par:boolean, par1:boo;ean )\n{\nsomething \n}";
    private static final String SIMPLE_FUNCTION_4 = "function   name  (par, par )\n{\nsomething \n somethin2\n}";
    private static final String SIMPLE_FUNCTION_5 = "function HorizontalRegion():void\n" + "{\n"
            + "     addEventListener(\"mouseDown\",startTracking);\n" + "}";

    private static final String SIMPLE_FUNCTION_6 = "something function name(){}";
    private static final String SIMPLE_FUNCTION_6_SUGGESTED = "function name(){}";
    private static final String INVALID_FUNCTION_2 = "function name(){}something";
    private static final String INVALID_FUNCTION_3 = "function   name  (par, par )\n{\n {something \n}";
    private static final String INVALID_FUNCTION_4 = "function name(par, par ):boolean:boolean\n{\nreturn true;\n}";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        checker = new ActionScriptFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is a valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is a valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is a valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        assertTrue("This is a valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_4).isCheckOnInternetNeaded());
        assertTrue("This is a valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_5).isCheckOnInternetNeaded());

        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_6);
        assertTrue("This string consist funstion: ", result.isCheckOnInternetNeaded());
        assertEquals("Function must be like this: ", SIMPLE_FUNCTION_6_SUGGESTED, result.getCodeSuggestedToBeChecked());
        assertFalse("There must be false returned because there is something after function definition", checker
                .checkByHeuristic(INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse("There must be false returned because the numbers of open and closed brackets are not equal",
                checker.checkByHeuristic(INVALID_FUNCTION_3).isCheckOnInternetNeaded());
        assertFalse("There must be false returned because there is error in return type definition", checker
                .checkByHeuristic(INVALID_FUNCTION_4).isCheckOnInternetNeaded());
    }

}
