/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;

import junit.framework.TestCase;

public class CSharpFunctionHeuristicCheckerTest extends TestCase {

    private CSharpFunctionHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "void name(){}";
    private static final String SIMPLE_FUNCTION_2 = "public static void name ()\n{}";
    private static final String SIMPLE_FUNCTION_3 = "public static void nameOfAFunction ( int pom, int pom2)\n{\n something;\n {\nsomething\n }\n}";

    private static final String SIMPLE_FUNCTION_4 = "something\npublic static void name (){}";
    private static final String SIMPLE_FUNCTION_4_SUGGESTED = "public static void name (){}";
    private static final String INVALID_FUNCTION_2 = "public static void name() {} something";
    private static final String INVALID_FUNCTION_3 = "public static void name() { \n{something }";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        checker = new CSharpFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_4);
        assertTrue("This string consist funstion", result.isCheckOnInternetNeaded());
        assertEquals("Suggested function must look like this:", SIMPLE_FUNCTION_4_SUGGESTED, result
                .getCodeSuggestedToBeChecked());
        assertFalse("There must be false return because there is something after function", checker.checkByHeuristic(
                INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse("There must be false return because the numbers of opened and closed brackets are not equal",
                checker.checkByHeuristic(INVALID_FUNCTION_3).isCheckOnInternetNeaded());
    }
}
