/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import junit.framework.TestCase;

public class FortranFunctionHeuristicCheckerTest extends TestCase {
    FortranFunctionHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_01 = "type FUNCTION nameOfAFunction ()return\nend function";
    private static final String SIMPLE_FUNCTION_02 = "type FUNCTION nameOfAFunction ()return end function\n";

    private static final String SIMPLE_FUNCTION_1 = "type FUNCTION nameOfAFunction ()\nend function   nameOfAFunction";
    private static final String SIMPLE_FUNCTION_2 = "type FUNCtION nameOfAFunction ()return  \n \nend function nameOfAFunction";
    private static final String SIMPLE_FUNCTION_3 = "type FUNCtION nameOfAFunction (int pom,  int pom2) \nsomething\nsomething2 \n  something  \n \nend    function nameOfAFunction";
    private static final String SIMPLE_FUNCTION_4 = "LOGICAL FUNCTION gt_person (a, b) !Greater Than Person is what it stands for\n"
            + "	! This function takes a person as the argument and figurs out which sorts out first\n"
            + "	!this is used as part of every sorting method we use\n"
            + "	USE types\n"
            + "	IMPLICIT NONE\n"
            + "\n"
            + "	TYPE(person), INTENT(IN)::a,b !grab the arguments and format them to make Fortran happy\n"
            + "\n"
            + "	gt_person = .FALSE.!if no other conditions are met then the second person comes first\n"
            + "	!WRITE (*,*) a%last, ' ', b%last\n"
            + "	last: IF (a%last==b%last) THEN !check the last name\n"
            + "		first: IF (a%first==b%first) then !check first name if last is same\n"
            + "			ssn: IF (a%ssn>b%ssn) then  !check SSN if both first and last are same\n"
            + "				gt_person = .TRUE.\n"
            + "				!WRITE (*,*) 'swapped because of ssn'\n"
            + "			END IF ssn\n"
            + "		else\n"
            + "			first2: IF (LLT ( b%first , a%first)) then !checking first if last matches\n"
            + "				gt_person = .TRUE.\n"
            + "				!WRITE (*,*) 'swapped because of first'\n"
            + "			END IF first2\n"
            + "		END IF first\n"
            + "	ELSE\n"
            + "		last2: IF (LLT ( b%last , a%last)) THEN !if nothing else we just check last (LLT adjusts for case sensitivy)\n"
            + "			gt_person = .TRUE.\n"
            + "			!WRITE (*,*) 'swapped because of last'\n"
            + "		END IF last2\n"
            + "	END IF last	\n" + "\n" + "END FUNCTION gt_person";

    private static final String SIMPLE_SUBRUTINE_6 = "SUBROUTINE name   (pom pom, pom)\n something\n \nend SUBROUTINE name";
    private static final String SIMPLE_SUBRUTINE_7 = "SUBROUTINE name   (pom pom, pom)\n something\n something\n \nend SUBROUTINE   name";
    private static final String SIMPLE_SUBRUTINE_8 = "SUBROUTINE sort_bubble (customer_list, nvals) !-----needs numvals and custlist\n"
            + "!this is where teh bubble sort is done\n"
            + "	USE types\n"
            + "	LOGICAL, EXTERNAL :: gt_person !funtion to tell which person goes first\n"
            + "	INTEGER :: i = 0\n"
            + "	INTEGER :: j = 0\n"
            + "	TYPE(person):: temp_person2\n"
            + "	TYPE(person), INTENT(INOUT), DIMENSION(*) :: customer_list !Define the customer list to handle whatever size is sent\n"
            + "	INTEGER, INTENT(IN) :: nvals !grab the number of values from the calling code\n"
            + "\n"
            + "	! Here is where we will do the selection sort\n"
            + "\n"
            + "	WRITE (*,*) 'Now doing a bubble sort'\n"
            + "\n"
            + "	sortloop1: DO i = nvals -1, 0, -1 !basically we just loop through every element to compare it against every other element\n"
            + "		!this loop increments i which is our starting point for the comparison\n"
            + "	 	sortloop2:DO j = 1, i, 1\n"
            + "		 	!this loop increments j which is the ending point for the comparison		\n"
            + "	 		swapposition: IF ( gt_person(customer_list(j-1),customer_list(j)) )  THEN\n"
            + "				!swap the name here\n"
            + "				temp_person2 = customer_list(j-1)\n"
            + "				customer_list(j-1) = customer_list(j)\n"
            + "				customer_list(j) = temp_person2\n"
            + "			END IF swapposition\n"
            + "		END DO sortloop2\n"
            + "	END DO sortloop1	\n"
            + "	"
            + " \n"
            + "END SUBROUTINE sort_bubble";

    private static final String INVALID_FUNCTION_1 = "FUNCTION nameOfAFunction ()return\nend function";
    private static final String INVALID_FUNCTION_2 = "type1 type2FUNCTION nameOfAFunction ()return\nend function";
    private static final String INVALID_SUBROUTINE_3 = "SUBROUTINE name   () end SUBROUTINE name";

    protected void setUp() throws Exception {
        checker = new FortranFunctionHeuristicChecker(0, System.out);
    }

    public void testCheckByHeuristic() {
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        assertTrue("This is a function - see http://www.andrewduey.com/cscs252d.htm", checker.checkByHeuristic(
                SIMPLE_FUNCTION_4).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_SUBRUTINE_6).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_SUBRUTINE_7).isCheckOnInternetNeaded());
        assertTrue("This is a function - see http://www.andrewduey.com/cscs252d.htm", checker.checkByHeuristic(
                SIMPLE_SUBRUTINE_8).isCheckOnInternetNeaded());

        assertFalse("There must be false returned because returning type of function is missing", checker
                .checkByHeuristic(INVALID_FUNCTION_1).isCheckOnInternetNeaded());
        assertFalse(
                "There must be false returned because there are two types of returning type of function and we can only have one",
                checker.checkByHeuristic(INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse("This is a function", checker.checkByHeuristic(INVALID_SUBROUTINE_3).isCheckOnInternetNeaded());

    }

    public void testGetFunctionHeader() {
        assertEquals("type FUNCTION nameOfAFunction ()return\n", checker.getFunctionHeader(SIMPLE_FUNCTION_01,
                FortranFunctionHeuristicChecker.FUNCTION_HEADER_REGEX));
        assertEquals("type FUNCTION nameOfAFunction ()return end function\n", checker.getFunctionHeader(
                SIMPLE_FUNCTION_02, FortranFunctionHeuristicChecker.FUNCTION_HEADER_REGEX));
        assertEquals("LOGICAL FUNCTION gt_person (a, b) !Greater Than Person is what it stands for\n", checker
                .getFunctionHeader(SIMPLE_FUNCTION_4, FortranFunctionHeuristicChecker.FUNCTION_HEADER_REGEX));
    }

    public void testGetFunctionName() {
        assertEquals("nameOfAFunction", checker.getFunctionName(SIMPLE_FUNCTION_01,
                FortranFunctionHeuristicChecker.FUNCTION_KEYWORD, FortranFunctionHeuristicChecker.FUNCTION_NAME_REGEX));
        assertEquals("nameOfAFunction", checker.getFunctionName(SIMPLE_FUNCTION_02,
                FortranFunctionHeuristicChecker.FUNCTION_KEYWORD, FortranFunctionHeuristicChecker.FUNCTION_NAME_REGEX));
        assertEquals("gt_person", checker.getFunctionName(SIMPLE_FUNCTION_4,
                FortranFunctionHeuristicChecker.FUNCTION_KEYWORD, FortranFunctionHeuristicChecker.FUNCTION_NAME_REGEX));
    }

}
