/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import junit.framework.TestCase;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;

public class JavaFunctionHeuristicCheckerTest extends TestCase {

    private JavaFunctionHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "public static String getClass(){" + "return super.getClass();"
            + "}";

    private static final String SIMPLE_FUNCTION_2 = "public static String getClass(){\n" + "return super.getClass();\n"
            + "}";

    private static final String SIMPLE_FUNCTION_3 = "String getClass(){\n" + "return super.getClass();\n" + "}";
    private static final String SIMPLE_FUNCTION_4 = "MyNewType getClass(){\n" + "\nreturn super.getClass();\n" + "}";
    private static final String SIMPLE_FUNCTION_5 = "public static String getClass  (){if (this){ \n" + "return 0; }}";

    private static final String SIMPLE_FUNCTION_6 = "public static String getFile() throws FileNotFoundException{"
            + "return super.getFile();" + "}";
    private static final String SIMPLE_FUNCTION_7 = "something\npublic static String getClass(){"
            + "return super.getClass();" + "}";
    private static final String SIMPLE_FUNCTION_7_SUGGESTION = "public static String getClass(){"
            + "return super.getClass();" + "}";

    private static final String SIMPLE_FUNCTION_8 = "public static List<String> getList()\n{"
            + "return super.getList();" + "}";;

    private static final String SIMPLE_FUNCTION_9 = " private void parseArguments(String[] args) throws ParseException,\n"
            + "                        NumberFormatException {\n"
            + "                CommandLineParser parser = new GnuParser();\n"
            + "                CommandLine line = parser.parse(options, args);\n"
            + "                parseCommandLineArguments(line);\n" + "        }";

    private static final String INVALID_FUNCTION_1 = "public static String getClass{\n" + "return super.getClass();\n"
            + "}";
    private static final String INVALID_FUNCTION_2 = "public static String getClass();";
    private static final String INVALID_FUNCTION_3 = "public static String getClass(){if(this) {return o;};";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        checker = new JavaFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_4).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_5).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_6).isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_7);
        assertTrue("This is a function", result.isCheckOnInternetNeaded());
        assertEquals("suggested code must look like this", SIMPLE_FUNCTION_7_SUGGESTION, result
                .getCodeSuggestedToBeChecked());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_8).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_9).isCheckOnInternetNeaded());

        assertFalse("This is not a valid  function", checker.checkByHeuristic(INVALID_FUNCTION_1)
                .isCheckOnInternetNeaded());
        assertFalse("This is not a valid  function", checker.checkByHeuristic(INVALID_FUNCTION_2)
                .isCheckOnInternetNeaded());
        assertFalse("This is not a valid  function", checker.checkByHeuristic(INVALID_FUNCTION_3)
                .isCheckOnInternetNeaded());

    }

}
