/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;

import junit.framework.TestCase;

public class JavaScriptFunctionHeuristicCheckerTest extends TestCase {
    private JavaScriptFunctionHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "function name(){}";
    private static final String SIMPLE_FUNCTION_2 = "function   name  ( par, par ){}";
    private static final String SIMPLE_FUNCTION_3 = "function   name  (par, par )\n{\nsomething \n}";
    private static final String SIMPLE_FUNCTION_4 = "function   name  (par, par )\n{\nsomething \n somethin2\n}";
    private static final String SIMPLE_FUNCTION_5 = "function average()\n" + "{\n"
            + "   var items = average.arguments.length\n" + "   var sum = 0\n" + "   for (i = 0; i < items;i++)\n"
            + "   {\n" + "      sum += average.arguments[i]\n" + "   }\n" + "   return (sum/items)\n" + "}";

    private static final String SIMPLE_FUNCTION_6 = "something function name(){}";
    private static final String SIMPLE_FUNCTION_6_SUGGESTED = "function name(){}";
    private static final String INVALID_FUNCTION_2 = "function name(){}something";
    private static final String INVALID_FUNCTION_3 = "function   name  (par, par )\n{\n {something \n}";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        checker = new JavaScriptFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is a function-basic one", checker.checkByHeuristic(SIMPLE_FUNCTION_1)
                .isCheckOnInternetNeaded());
        assertTrue("This is a function-basic one", checker.checkByHeuristic(SIMPLE_FUNCTION_2)
                .isCheckOnInternetNeaded());
        assertTrue("This is a function-basic one", checker.checkByHeuristic(SIMPLE_FUNCTION_3)
                .isCheckOnInternetNeaded());
        assertTrue("This is a function-basic one", checker.checkByHeuristic(SIMPLE_FUNCTION_4)
                .isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_5).isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_6);
        assertTrue("There must be false returned because there is something before function", result
                .isCheckOnInternetNeaded());
        assertEquals("Sugested code must be: ", SIMPLE_FUNCTION_6_SUGGESTED, result.getCodeSuggestedToBeChecked());
        assertFalse("There must be false returned because there is something after function", checker.checkByHeuristic(
                INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse(
                "There must be false returned because the numers of open brackets and closed brackets are not equal",
                checker.checkByHeuristic(INVALID_FUNCTION_3).isCheckOnInternetNeaded());

    }
}
