/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;

import junit.framework.TestCase;

public class PHPFunctionHeuristicCheckerTest extends TestCase {
    private IHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "function a($n){return ( b($n) * $n );}";
    private static final String SIMPLE_FUNCTION_2 = "function smarty_function_math($params, &$smarty)\n" + "{\n"
            + "    // be sure equation parameter is present\n" + "    if (empty($params['equation'])) {\n"
            + "        $smarty->trigger_error(\"math: missing equation parameter\");\n" + "        return;" + "    }"
            + ";\n" + "}";
    private static final String SIMPLE_FUNCTION_3 = "function getRequestParam ($name, $default_value = false, $sanitize = false)  {\n"
            + "        if (!isset($_REQUEST[$name]))\n"
            + "                return $default_value;\n"
            + "\n"
            + "        if (is_array($_REQUEST[$name])) {\n"
            + "                $newarray = array();\n"
            + "\n"
            + "                foreach ($_REQUEST[$name] as $name => $value)\n"
            + "                        $newarray[formatParam($name, $sanitize)] = formatParam($value, $sanitize);\n"
            + "\n"
            + "                return $newarray;\n"
            + "        }\n"
            + "\n"
            + "        return formatParam($_REQUEST[$name], $sanitize);" + "}";

    private static final String SIMPLE_FUNCTION_4 = "something function name(){}";
    private static final String SIMPLE_FUNCTION_4_SUGGESTED = "function name(){}";
    private static final String INVALID_FUNCTION_2 = "function name(){}something";
    private static final String INVALID_FUNCTION_3 = "function name(){ {}";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        checker = new PHPFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is function in PHP", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is function in PHP", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is function in PHP", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_4);
        assertTrue("This strig consist function", result.isCheckOnInternetNeaded());
        assertEquals("Sugested code must be: ", SIMPLE_FUNCTION_4_SUGGESTED, result.getCodeSuggestedToBeChecked());
        assertFalse("There must be false return because there is something after function", checker.checkByHeuristic(
                INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse("There must be false return because the numbers of open and closed brackets are not equal", checker
                .checkByHeuristic(INVALID_FUNCTION_3).isCheckOnInternetNeaded());

    }

}
