/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import junit.framework.TestCase;

public class PascalFunctionHeuristicCheckerTest extends TestCase {

    private PascalFunctionHeuristicChecker checker;

    private static final String SIMPLE_FUNCTION_1 = "procEdure name (\n);BeGIN  END;";
    private static final String SIMPLE_FUNCTION_2 = "procedure name()   ;    BEGIN true ;\n END;";
    private static final String SIMPLE_FUNCTION_3 = "procedure name (int: str1, void: str2);BEGIN true ;\n END;";
    private static final String SIMPLE_FUNCTION_4 = "function name ()  : type  ; BEGIN END;";
    private static final String SIMPLE_FUNCTION_5 = "funCtion   name (   int: prom1): type  ; BEGiN something;  END;";

    private static final String INVALID_FUNCTION_1 = "procedure (\n) Begin End";
    private static final String INVALID_FUNCTION_2 = "function name():type BEGIN END";
    private static final String INVALID_FUNCTION_3 = "function name():type; BEGIN something Begin END";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        checker = new PascalFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristic() {
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_1).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_4).isCheckOnInternetNeaded());
        assertTrue("This is a function", checker.checkByHeuristic(SIMPLE_FUNCTION_5).isCheckOnInternetNeaded());

        assertFalse("This is not a function", checker.checkByHeuristic(INVALID_FUNCTION_1).isCheckOnInternetNeaded());
        assertFalse("This is not a function because there is not a ; after type which is ", checker.checkByHeuristic(
                INVALID_FUNCTION_2).isCheckOnInternetNeaded());
        assertFalse("This is not a function because the numbers of begins and ends are not equal", checker
                .checkByHeuristic(INVALID_FUNCTION_3).isCheckOnInternetNeaded());

    }
}