/*
 * 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 */
package org.apache.rat.pd.heuristic.functions;

import org.apache.rat.pd.heuristic.HeuristicCheckerResult;
import org.apache.rat.pd.heuristic.IHeuristicChecker;

import junit.framework.TestCase;

public class VisualBasicFunctionHeuristicCheckerTest extends TestCase {
    private IHeuristicChecker checker;

    private static final String SIMPLE_SUBROUTINE_1 = "Sub TestSub()End Sub";
    private static final String SIMPLE_SUBROUTINE_2 = "Sub  TestSub ()\n End Sub";
    private static final String SIMPLE_SUBROUTINE_3 = "Sub TestSub()\n" + "    MsgBox \"Code in TestSub()\"\n"
            + "End Sub";
    private static final String SIMPLE_SUBROUTINE_4 = "Private Sub Form_Load()\n"
            + "    MsgBox \"Code in Form_Load()\"\n"
            + "    'This line is functionally equal as the line in the previous example\n" + "    Call TestSub\n"
            + "    MsgBox \"Back in Form_Load()\"\n" + "End Sub";

    private static final String SIMPLE_FUNCTION_1 = "Function TestSub()As Integer End Function";
    private static final String SIMPLE_FUNCTION_2 = "Private Function Add(ByVal x As Integer, ByVal y As Integer) As Integer\n"
            + "    Dim Res as integer\n" + "    Res = x + y\n" + "    Add = Res\n" + "End Function";

    private static final String SIMPLE_FUNCTION_3 = "Function StripNulls(OriginalStr As String)   As String\n"
            + "   If (InStr(OriginalStr, Chr(0)) > 0) Then\n"
            + "       OriginalStr = Left(OriginalStr, InStr(OriginalStr, Chr(0)) - 1)\n" + "   End If\n"
            + "   StripNulls = OriginalStr\n" + "End Function";

    private static final String SIMPLE_SUBROUTINE_5 = "private public Sub TestSub()End Sub";
    private static final String SIMPLE_SUBROUTINE_5_SUGGESTED = "public Sub TestSub()End Sub";
    private static final String INVALID_SUBROUTINE_2 = "Sub TestSub()End Sub something";
    private static final String SIMPLE_FUNCTION_4 = "something Function TestSub()As Integer End Function";
    private static final String SIMPLE_FUNCTION_4_SUGGESTED = "Function TestSub()As Integer End Function";
    private static final String INVALID_FUNCTION_2 = "Function TestSub()As Integer End Function something";

    /*
     * (non-Javadoc)
     * 
     * @see junit.framework.TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        checker = new VisualBasicFunctionHeuristicChecker(0, System.out);
    }

    /**
     * Test method for
     * {@link org.apache.rat.pd.heuristic.functions.FunctionHeuristicChecker#checkByHeuristic(java.lang.String)}
     * .
     */
    public void testCheckByHeuristicFunctions() {

        assertTrue("This is valid function-basic one", checker.checkByHeuristic(SIMPLE_FUNCTION_1)
                .isCheckOnInternetNeaded());
        assertTrue("This is valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_2).isCheckOnInternetNeaded());
        assertTrue("This is valid function", checker.checkByHeuristic(SIMPLE_FUNCTION_3).isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_FUNCTION_4);
        assertTrue("This string consist function", result.isCheckOnInternetNeaded());
        assertEquals("Suggested functions must look like this:", SIMPLE_FUNCTION_4_SUGGESTED, result
                .getCodeSuggestedToBeChecked());
        assertFalse("There must be false returned because there is something after declaration of function", checker
                .checkByHeuristic(INVALID_FUNCTION_2).isCheckOnInternetNeaded());

    }

    public void testCheckByHeuristicsSubroutines() {
        assertTrue("This is valid subroutine-basic one", checker.checkByHeuristic(SIMPLE_SUBROUTINE_1)
                .isCheckOnInternetNeaded());
        assertTrue("This is valid subroutine-basic one", checker.checkByHeuristic(SIMPLE_SUBROUTINE_2)
                .isCheckOnInternetNeaded());
        assertTrue("This is valid subroutine", checker.checkByHeuristic(SIMPLE_SUBROUTINE_3).isCheckOnInternetNeaded());
        assertTrue("This is valid subroutine set as private", checker.checkByHeuristic(SIMPLE_SUBROUTINE_4)
                .isCheckOnInternetNeaded());
        HeuristicCheckerResult result = checker.checkByHeuristic(SIMPLE_SUBROUTINE_5);
        assertTrue("This string consist funstion", result.isCheckOnInternetNeaded());
        assertEquals("Suggested funstion must look like this", SIMPLE_SUBROUTINE_5_SUGGESTED, result
                .getCodeSuggestedToBeChecked());
        assertFalse("There must be false returned because there is something after declaration of subroutine", checker
                .checkByHeuristic(INVALID_SUBROUTINE_2).isCheckOnInternetNeaded());

    }
}
